ActionParameterDef class

Constructors

ActionParameterDef({required String type, required String description, List<String>? enumValues, bool required = true})

Properties

description String
final
enumValues List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited