AiMessage class

Constructors

AiMessage({required String role, required Object content, String? previewText, int? timestamp})

Properties

content Object
final
hashCode int
The hash code for this object.
no setterinherited
previewText String
final
role String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited