AiZoneConfig class

Constructors

AiZoneConfig({required String id, String? description, bool allowSimplify = false, bool allowGuide = false, bool allowHighlight = true, bool allowInjectBlock = false, bool allowInjectCard = false, bool interventionEligible = false, bool proactiveIntervention = false, List<BlockDefinition> blocks = const []})

Properties

allowGuide bool
final
allowHighlight bool
final
allowInjectBlock bool
final
allowInjectCard bool
final
allowSimplify bool
final
blocks List<BlockDefinition>
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
interventionEligible bool
final
proactiveIntervention bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited