AnalyticsLabeling class

Analytics labeling service.

Constructors

AnalyticsLabeling()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

chooseBestTarget(List<InteractiveElement> elements) AnalyticsTargetMetadata?
Choose the best analytics target from multiple elements. Used when multiple elements are under the touch point.
extractMetadata(InteractiveElement element) AnalyticsTargetMetadata
Extract the best analytics label from an interactive element.
getAnalyticsElementKind(AnalyticsElementKind kind) String
Get analytics element kind as string.
getLabelConfidence(AnalyticsLabelConfidence confidence) String
Get label confidence as string.