BlockDefinition class

Constructors

BlockDefinition({required String name, required BlockWidgetBuilder builder, List<BlockPlacement> allowedPlacements = const [BlockPlacement.chat, BlockPlacement.zone], Map<String, DataFieldDef>? propSchema, BlockPreviewTextBuilder? previewTextBuilder, BlockInterventionType interventionType = BlockInterventionType.none, bool interventionEligible = false, List<String> styleSlots = const []})
const

Properties

allowedPlacements List<BlockPlacement>
final
builder BlockWidgetBuilder
final
hashCode int
The hash code for this object.
no setterinherited
interventionEligible bool
final
interventionType BlockInterventionType
final
name String
final
previewTextBuilder BlockPreviewTextBuilder?
final
propSchema Map<String, DataFieldDef>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleSlots List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited