CSATConfig class

Constructors

CSATConfig({bool enabled = true, CSATSurveyType? surveyType, String? question, CSATRatingType? ratingType, Future<void> onSubmit(int rating, String? feedback)?, int? showAfterIdleSeconds})
const

Properties

enabled bool
Enable CSAT survey after conversation. Default: true if support mode enabled
final
hashCode int
The hash code for this object.
no setterinherited
onSubmit Future<void> Function(int rating, String? feedback)?
Callback when user submits rating
final
question String?
Question text. Default varies by surveyType
final
ratingType CSATRatingType?
Rating type. Default: 'emoji'
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAfterIdleSeconds int?
Show after N seconds of inactivity. Default: 10
final
surveyType CSATSurveyType?
Which survey to show. 'csat' = Customer Satisfaction, 'ces' = Customer Effort Score.
final

Methods

copyWith({bool? enabled, CSATSurveyType? surveyType, String? question, CSATRatingType? ratingType, Future<void> onSubmit(int rating, String? feedback)?, int? showAfterIdleSeconds}) CSATConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited