PiiScrubber class
PII Scrubber — Removes personally identifiable information from telemetry.
Patterns matched:
- Email addresses
- Phone numbers
- Credit card numbers
- SSN (US)
- IP addresses
- Physical addresses (basic)
Constructors
- PiiScrubber()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scrub(
String text) → String - Scrub PII from text string
-
scrubAddress(
String text) → String -
Scrub address patterns - replace with
ADDRESS -
scrubMap(
Map< String, dynamic> data) → Map<String, dynamic> - Scrub all sensitive data from a map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited