SupportTicket class

Constructors

SupportTicket({required String id, required String reason, required String screen, String status = 'open', List<ChatMessage> history = const [], required String createdAt, required String wsUrl, int unreadCount = 0})
const

Properties

createdAt String
final
hashCode int
The hash code for this object.
no setterinherited
history List<ChatMessage>
final
id String
final
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen String
final
status String
final
unreadCount int
final
wsUrl String
final

Methods

copyWith({String? id, String? reason, String? screen, String? status, List<ChatMessage>? history, String? createdAt, String? wsUrl, int? unreadCount}) SupportTicket
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited