TelemetryConfig class

Configuration for the telemetry service.

Constructors

TelemetryConfig({bool enabled = true, String? analyticsKey, String? baseUrl, Map<String, String>? headers, String? userId, String? sessionId})
const

Properties

analyticsKey String?
final
baseUrl String?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited