VoiceServiceCallbacks class

Constructors

VoiceServiceCallbacks({void onAudioResponse(String base64Audio)?, void onToolCall(VoiceToolCall toolCall)?, void onToolCallCancellation(List<String> ids)?, void onTranscript(String text, bool isFinal, String role)?, void onStatusChange(String base64Audio)?, void onError(String base64Audio)?, void onTurnComplete()?, void onSetupComplete()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onAudioResponse → void Function(String base64Audio)?
final
onError → void Function(String base64Audio)?
final
onSetupComplete → void Function()?
final
onStatusChange → void Function(String base64Audio)?
final
onToolCall → void Function(VoiceToolCall toolCall)?
final
onToolCallCancellation → void Function(List<String> ids)?
final
onTranscript → void Function(String text, bool isFinal, String role)?
final
onTurnComplete → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited