AIAgentController class
Constructors
-
AIAgentController({required AgentRuntime runtime, required Future<
void> send(String instruction), Future<void> openConversation(String conversationId)?, required VoidCallback cancel, required VoidCallback clearMessages, required VoidCallback startNewConversation, required bool isRunning, bool isAwaitingUserResponse = false, bool isLoadingHistory = false, ExecutionResult? lastResult, String status = '', List<AiMessage> messages = const [], List<ConversationSummary> conversations = const []})
Properties
- cancel → VoidCallback
-
final
- clearMessages → VoidCallback
-
final
-
conversations
→ List<
ConversationSummary> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAwaitingUserResponse → bool
-
final
- isLoadingHistory → bool
-
final
- isRunning → bool
-
final
- lastResult → ExecutionResult?
-
final
-
messages
→ List<
AiMessage> -
final
-
openConversation
→ Future<
void> Function(String conversationId)? -
final
- runtime → AgentRuntime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
send
→ Future<
void> Function(String instruction) -
final
- startNewConversation → VoidCallback
-
final
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited