AudioInputService class
Constructors
- AudioInputService(AudioInputConfig config)
Properties
- config → AudioInputConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMuted → bool
-
no setter
- isRecording → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
hasPermission(
{bool request = false}) → Future< bool> -
mute(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< bool> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
unmute(
) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited