CSATRating class
Constructors
- CSATRating({required int score, String? feedback, required CSATMetadata metadata})
-
const
Properties
- feedback → String?
-
Optional text feedback
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → CSATMetadata
-
Conversation metadata
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → int
-
Numeric score (1-5 for stars/emoji, 0-1 for thumbs)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited