DataDefinition class
Constructors
-
DataDefinition({required String name, required String description, Map<
String, DataFieldDef> ? schema, required FutureOr<Object?> handler(DataQueryContext context)}) -
const
Properties
- description → String
-
final
-
handler
→ FutureOr<
Object?> Function(DataQueryContext context) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schema
→ Map<
String, DataFieldDef> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited