ScreenSnapshot class
Constructors
-
ScreenSnapshot({required String screenName, required List<
String> availableScreens, required String elementsText, List<InteractiveElement> elements = const [], List<ZoneSnapshot> zones = const []}) -
const
Properties
-
availableScreens
→ List<
String> -
final
-
elements
→ List<
InteractiveElement> -
final
- elementsText → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenName → String
-
final
-
zones
→ List<
ZoneSnapshot> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited