VerificationSnapshot class
Snapshot of screen state for verification.
Constructors
-
VerificationSnapshot({required String screenName, required String screenContent, required List<
InteractiveElement> elements, String? screenshot}) -
const
Properties
-
elements
→ List<
InteractiveElement> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenContent → String
-
final
- screenName → String
-
final
- screenshot → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited